@@ -32,6 +32,7 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 #include <boost/program_options.hpp>
 
+#include <algorithm>
 #include <functional>
 #include <map>
 #include <memory>
@@ -117,7 +118,7 @@ public:
         return m_osm_entity_bits;
     }
 
-    bool display_progress() const {
+    bool display_progress_internal() const {
         switch (m_display_progress) {
             case display_progress_type::on_tty:
                 return osmium::isatty(1) && osmium::isatty(2); // if STDOUT and STDERR are a TTY
@@ -151,6 +152,11 @@ public:
         return m_input_file;
     }
 
+    /// Is the input file STDIN?
+    bool any_input_is_stdin() const noexcept {
+        return m_input_file.filename().empty();
+    }
+
 }; // class with_single_osm_input
 
 class with_multiple_osm_inputs {
@@ -173,8 +179,44 @@ public:
         return m_input_files;
     }
 
+    /// Is any of the input files STDIN?
+    bool any_input_is_stdin() const noexcept {
+        return std::any_of(m_input_files.cbegin(), m_input_files.cend(),
+            [](const osmium::io::File& file) {
+                return file.filename().empty();
+            });
+    }
+
 }; // class with_multiple_osm_inputs
 
+class CommandWithSingleOSMInput : public Command, public with_single_osm_input {
+
+public:
+
+    explicit CommandWithSingleOSMInput(const CommandFactory& command_factory) :
+        Command(command_factory) {
+    }
+
+    bool display_progress() const {
+        return display_progress_internal() && !any_input_is_stdin();
+    }
+
+}; // class CommandWithSingleOSMInput
+
+class CommandWithMultipleOSMInputs : public Command, public with_multiple_osm_inputs {
+
+public:
+
+    explicit CommandWithMultipleOSMInputs(const CommandFactory& command_factory) :
+        Command(command_factory) {
+    }
+
+    bool display_progress() const {
+        return display_progress_internal() && !any_input_is_stdin();
+    }
+
+}; // class CommandWithMultipleOSMInputs
+
 void init_header(osmium::io::Header& header, const osmium::io::Header& input_header, const std::vector<std::string>& options);
 
 class with_osm_output {
@@ -254,6 +296,6 @@ public:
 }; // class CommandFactory
 
 void register_commands(CommandFactory& cmd_factory);
-std::string check_index_type(const std::string& index_type_name);
+std::string check_index_type(const std::string& index_type_name, bool allow_none = false);
 
 #endif // CMD_HPP
