@@ -32,7 +32,7 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #include <string>
 #include <vector>
 
-class CommandCat : public Command, public with_multiple_osm_inputs, public with_osm_output {
+class CommandCat : public CommandWithMultipleOSMInputs, public with_osm_output {
 
     enum clean_options : uint8_t {
         clean_version   = 0x01,
@@ -44,12 +44,20 @@ class CommandCat : public Command, public with_multiple_osm_inputs, public with_
 
     uint8_t m_clean_attrs = 0;
 
+    bool m_buffer_data = false;
+
+    void clean_buffer(osmium::memory::Buffer& buffer) const;
+
     void copy(osmium::ProgressBar& progress_bar, osmium::io::Reader& reader, osmium::io::Writer &writer) const;
 
+    std::size_t read_buffers(osmium::ProgressBar& progress_bar, osmium::io::Reader& reader, std::vector<osmium::memory::Buffer>& buffers);
+
+    void write_buffers(osmium::ProgressBar& progress_bar, std::vector<osmium::memory::Buffer>& buffers, osmium::io::Writer &writer);
+
 public:
 
     explicit CommandCat(const CommandFactory& command_factory) :
-        Command(command_factory) {
+        CommandWithMultipleOSMInputs(command_factory) {
     }
 
     bool setup(const std::vector<std::string>& arguments) override final;
