@@ -272,6 +272,7 @@ bool CommandExport::setup(const std::vector<std::string>& arguments) {
     ("show-errors,e", "Output any geometry errors on STDOUT")
     ("stop-on-error,E", "Stop on the first error encountered")
     ("show-index-types,I", "Show available index types")
+    ("attributes,a", po::value<std::string>(), "Comma-separated list of attributes to add to the output (default: none)")
     ("omit-rs,r", "Do not print RS (record separator) character when using JSON Text Sequences")
     ;
 
@@ -412,8 +413,33 @@ bool CommandExport::setup(const std::vector<std::string>& arguments) {
         }
     }
 
+    if (vm.count("attributes")) {
+        const auto attrs = osmium::split_string(vm["attributes"].as<std::string>(), ',');
+        for (const auto& attr : attrs) {
+            if (attr == "type") {
+                m_options.type = "@type";
+            } else if (attr == "id") {
+                m_options.id = "@id";
+            } else if (attr == "version") {
+                m_options.version = "@version";
+            } else if (attr == "changeset") {
+                m_options.changeset = "@changeset";
+            } else if (attr == "timestamp") {
+                m_options.timestamp = "@timestamp";
+            } else if (attr == "uid") {
+                m_options.uid = "@uid";
+            } else if (attr == "user") {
+                m_options.user = "@user";
+            } else if (attr == "way_nodes") {
+                m_options.way_nodes = "@way_nodes";
+            } else {
+                throw argument_error{"Unknown attribute in --attributes option: " + attr + "."};
+            }
+        }
+    }
+
     if (vm.count("index-type")) {
-        m_index_type_name = check_index_type(vm["index-type"].as<std::string>());
+        m_index_type_name = check_index_type(vm["index-type"].as<std::string>(), true);
     }
 
     if (vm.count("keep-untagged")) {
