@@ -230,7 +230,7 @@ public:
         std::cout << "  Compression: " << input_file.compression() << "\n";
 
         if (!input_file.filename().empty()) {
-            std::cout << "  Size: " << osmium::file_size(input_file.filename()) << "\n";
+            std::cout << "  Size: " << file_size(input_file) << "\n";
         }
     }
 
@@ -348,7 +348,7 @@ public:
 
         if (!input_file.filename().empty()) {
             m_writer.String("size");
-            m_writer.Int64(osmium::file_size(input_file.filename()));
+            m_writer.Int64(file_size(input_file));
         }
 
         m_writer.EndObject();
@@ -537,13 +537,19 @@ public:
             if (input_file.filename().empty()) {
                 std::cout << 0 << "\n";
             } else {
-                std::cout << osmium::file_size(input_file.filename()) << "\n";
+                std::cout << file_size(input_file) << "\n";
             }
             return;
         }
     }
 
     void header(const osmium::io::Header& header) final {
+        if (m_get_value == "header.boxes") {
+            for (const auto& box : header.boxes()) {
+                std::cout << box << "\n";
+            }
+        }
+
         if (m_get_value == "header.with_history") {
             std::cout << yes_no(header.has_multiple_object_versions());
             return;
@@ -770,6 +776,7 @@ bool CommandFileinfo::setup(const std::vector<std::string>& arguments) {
         "file.format",
         "file.compression",
         "file.size",
+        "header.boxes",
         "header.with_history",
         "header.option.generator",
         "header.option.osmosis_replication_base_url",
