@@ -28,14 +28,14 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #include <string>
 #include <vector>
 
-class CommandMergeChanges : public Command, public with_multiple_osm_inputs, public with_osm_output {
+class CommandMergeChanges : public CommandWithMultipleOSMInputs, public with_osm_output {
 
     bool m_simplify_change = false;
 
 public:
 
     explicit CommandMergeChanges(const CommandFactory& command_factory) :
-        Command(command_factory) {
+        CommandWithMultipleOSMInputs(command_factory) {
     }
 
     bool setup(const std::vector<std::string>& arguments) override final;
