@@ -67,11 +67,18 @@ void warning(const std::string& text) {
     std::cerr << "WARNING: " << text;
 }
 
+std::size_t file_size(const osmium::io::File& file) {
+    if (file.filename().empty()) {
+        return 0;
+    }
+    return osmium::file_size(file.filename());
+}
+
 std::size_t file_size_sum(const std::vector<osmium::io::File>& files) {
     std::size_t sum = 0;
 
     for (const auto& file : files) {
-        sum += osmium::file_size(file.filename());
+        sum += file_size(file);
     }
 
     return sum;
@@ -249,3 +256,12 @@ const char* object_type_as_string(const osmium::OSMObject& object) noexcept {
     return osmium::item_type_to_name(object.type());
 }
 
+bool ends_with(const std::string& str, const std::string& suffix) {
+    if (suffix.size() > str.size()) {
+        return false;
+    }
+
+    return std::strcmp(str.c_str() + (str.size() - suffix.size()),
+                       suffix.c_str()) == 0;
+}
+
